@@ -6,14 +6,14 @@ from .common import TestCase
 
 
 class TestAudioFrameConstructors(TestCase):
-    def test_null_constructor(self):
+    def test_null_constructor(self) -> None:
         frame = AudioFrame()
         self.assertEqual(frame.format.name, "s16")
         self.assertEqual(frame.layout.name, "stereo")
         self.assertEqual(len(frame.planes), 0)
         self.assertEqual(frame.samples, 0)
 
-    def test_manual_flt_mono_constructor(self):
+    def test_manual_flt_mono_constructor(self) -> None:
         frame = AudioFrame(format="flt", layout="mono", samples=160)
         self.assertEqual(frame.format.name, "flt")
         self.assertEqual(frame.layout.name, "mono")
@@ -21,7 +21,7 @@ class TestAudioFrameConstructors(TestCase):
         self.assertEqual(frame.planes[0].buffer_size, 640)
         self.assertEqual(frame.samples, 160)
 
-    def test_manual_flt_stereo_constructor(self):
+    def test_manual_flt_stereo_constructor(self) -> None:
         frame = AudioFrame(format="flt", layout="stereo", samples=160)
         self.assertEqual(frame.format.name, "flt")
         self.assertEqual(frame.layout.name, "stereo")
@@ -29,7 +29,7 @@ class TestAudioFrameConstructors(TestCase):
         self.assertEqual(frame.planes[0].buffer_size, 1280)
         self.assertEqual(frame.samples, 160)
 
-    def test_manual_fltp_stereo_constructor(self):
+    def test_manual_fltp_stereo_constructor(self) -> None:
         frame = AudioFrame(format="fltp", layout="stereo", samples=160)
         self.assertEqual(frame.format.name, "fltp")
         self.assertEqual(frame.layout.name, "stereo")
@@ -38,7 +38,7 @@ class TestAudioFrameConstructors(TestCase):
         self.assertEqual(frame.planes[1].buffer_size, 640)
         self.assertEqual(frame.samples, 160)
 
-    def test_manual_s16_mono_constructor(self):
+    def test_manual_s16_mono_constructor(self) -> None:
         frame = AudioFrame(format="s16", layout="mono", samples=160)
         self.assertEqual(frame.format.name, "s16")
         self.assertEqual(frame.layout.name, "mono")
@@ -46,7 +46,7 @@ class TestAudioFrameConstructors(TestCase):
         self.assertEqual(frame.planes[0].buffer_size, 320)
         self.assertEqual(frame.samples, 160)
 
-    def test_manual_s16_mono_constructor_align_8(self):
+    def test_manual_s16_mono_constructor_align_8(self) -> None:
         frame = AudioFrame(format="s16", layout="mono", samples=159, align=8)
         self.assertEqual(frame.format.name, "s16")
         self.assertEqual(frame.layout.name, "mono")
@@ -54,7 +54,7 @@ class TestAudioFrameConstructors(TestCase):
         self.assertEqual(frame.planes[0].buffer_size, 320)
         self.assertEqual(frame.samples, 159)
 
-    def test_manual_s16_stereo_constructor(self):
+    def test_manual_s16_stereo_constructor(self) -> None:
         frame = AudioFrame(format="s16", layout="stereo", samples=160)
         self.assertEqual(frame.format.name, "s16")
         self.assertEqual(frame.layout.name, "stereo")
@@ -62,7 +62,7 @@ class TestAudioFrameConstructors(TestCase):
         self.assertEqual(frame.planes[0].buffer_size, 640)
         self.assertEqual(frame.samples, 160)
 
-    def test_manual_s16p_stereo_constructor(self):
+    def test_manual_s16p_stereo_constructor(self) -> None:
         frame = AudioFrame(format="s16p", layout="stereo", samples=160)
         self.assertEqual(frame.format.name, "s16p")
         self.assertEqual(frame.layout.name, "stereo")
@@ -73,7 +73,7 @@ class TestAudioFrameConstructors(TestCase):
 
 
 class TestAudioFrameConveniences(TestCase):
-    def test_basic_to_ndarray(self):
+    def test_basic_to_ndarray(self) -> None:
         frame = AudioFrame(format="s16p", layout="stereo", samples=160)
         array = frame.to_ndarray()
         self.assertEqual(array.dtype, "i2")
