@@ -4,7 +4,7 @@ from fractions import Fraction
 from unittest import SkipTest
 
 import av
-from av import AudioResampler, Codec, Packet
+from av import AudioLayout, AudioResampler, Codec, Packet
 from av.codec.codec import UnknownCodecError
 from av.video.frame import PictureType
 
@@ -96,17 +96,6 @@ class TestCodecContext(TestCase):
                 "Using VideoCodecContext.gop_size for decoders is deprecated.",
             )
 
-    def test_frame_index(self):
-        container = av.open(fate_suite("h264/interlaced_crop.mp4"))
-        stream = container.streams[0]
-        for frame in container.decode(stream):
-            with warnings.catch_warnings(record=True) as captured:
-                self.assertIsInstance(frame.index, int)
-                self.assertEqual(
-                    captured[0].message.args[0],
-                    "Using `frame.index` is deprecated.",
-                )
-
     def test_decoder_timebase(self):
         ctx = av.codec.Codec("h264", "r").create()
 
@@ -393,6 +382,12 @@ class TestEncoding(TestCase):
     maxDiff = None
 
     def audio_encoding(self, codec_name):
+        self._audio_encoding(codec_name=codec_name, channel_layout="stereo")
+        self._audio_encoding(
+            codec_name=codec_name, channel_layout=AudioLayout("stereo")
+        )
+
+    def _audio_encoding(self, *, codec_name, channel_layout):
         try:
             codec = Codec(codec_name, "w")
         except UnknownCodecError:
@@ -404,14 +399,12 @@ class TestEncoding(TestCase):
 
         sample_fmt = ctx.codec.audio_formats[-1].name
         sample_rate = 48000
-        channel_layout = "stereo"
         channels = 2
 
         ctx.time_base = Fraction(1) / sample_rate
         ctx.sample_rate = sample_rate
         ctx.format = sample_fmt
         ctx.layout = channel_layout
-        ctx.channels = channels
 
         ctx.open()
 
@@ -549,7 +542,6 @@ class TestEncoding(TestCase):
         ctx.sample_rate = sample_rate
         ctx.format = sample_fmt
         ctx.layout = channel_layout
-        ctx.channels = channels
         ctx.open()
 
         result_samples = 0
