@@ -7,7 +7,7 @@ from .common import TestCase
 
 class TestDeprecations(TestCase):
     def test_method(self):
-        class Example(object):
+        class Example:
             def __init__(self, x=100):
                 self.x = x
 
@@ -22,8 +22,7 @@ class TestDeprecations(TestCase):
             self.assertIn("Example.foo is deprecated", captured[0].message.args[0])
 
     def test_renamed_attr(self):
-        class Example(object):
-
+        class Example:
             new_value = "foo"
             old_value = deprecation.renamed_attr("new_value")
 
@@ -35,7 +34,6 @@ class TestDeprecations(TestCase):
         obj = Example()
 
         with warnings.catch_warnings(record=True) as captured:
-
             self.assertEqual(obj.old_value, "foo")
             self.assertIn(
                 "Example.old_value is deprecated", captured[0].message.args[0]
