@@ -128,14 +128,9 @@ class TestFilters(TestCase):
             if e.errno != errno.EAGAIN:
                 raise
 
-    @staticmethod
-    def link_nodes(*nodes):
-        for c, n in zip(nodes, nodes[1:]):
-            c.link_to(n)
-
     def test_audio_buffer_resample(self):
         graph = Graph()
-        self.link_nodes(
+        graph.link_nodes(
             graph.add_abuffer(
                 format="fltp",
                 sample_rate=48000,
@@ -146,8 +141,7 @@ class TestFilters(TestCase):
                 "aformat", "sample_fmts=s16:sample_rates=44100:channel_layouts=stereo"
             ),
             graph.add("abuffersink"),
-        )
-        graph.configure()
+        ).configure()
 
         graph.push(
             generate_audio_frame(
@@ -161,7 +155,7 @@ class TestFilters(TestCase):
 
     def test_audio_buffer_volume_filter(self):
         graph = Graph()
-        self.link_nodes(
+        graph.link_nodes(
             graph.add_abuffer(
                 format="fltp",
                 sample_rate=48000,
@@ -170,8 +164,7 @@ class TestFilters(TestCase):
             ),
             graph.add("volume", volume="0.5"),
             graph.add("abuffersink"),
-        )
-        graph.configure()
+        ).configure()
 
         input_frame = generate_audio_frame(
             0, input_format="fltp", layout="stereo", sample_rate=48000
@@ -204,7 +197,7 @@ class TestFilters(TestCase):
 
         for frame in input_container.decode():
             self.assertEqual(frame.time_base, Fraction(1, 30))
-            graph.push(frame)
+            graph.vpush(frame)
             filtered_frames = pull_until_blocked(graph)
 
             if frame.pts == 0:
@@ -220,7 +213,7 @@ class TestFilters(TestCase):
                 self.assertEqual(filtered_frames[1].pts, (frame.pts - 1) * 2 + 1)
                 self.assertEqual(filtered_frames[1].time_base, Fraction(1, 60))
 
-    def test_EOF(self):
+    def test_EOF(self) -> None:
         input_container = av.open(format="lavfi", file="color=c=pink:duration=1:r=30")
         video_stream = input_container.streams.video[0]
 
@@ -233,12 +226,12 @@ class TestFilters(TestCase):
         graph.configure()
 
         for frame in input_container.decode(video=0):
-            graph.push(frame)
+            graph.vpush(frame)
 
-        graph.push(None)
+        graph.vpush(None)
 
         # if we do not push None, we get a BlockingIOError
-        palette_frame = graph.pull()
+        palette_frame = graph.vpull()
 
         self.assertIsInstance(palette_frame, av.VideoFrame)
         self.assertEqual(palette_frame.width, 16)
