@@ -5,7 +5,7 @@ from .common import TestCase, fate_suite
 
 
 class TestSubtitle(TestCase):
-    def test_movtext(self):
+    def test_movtext(self) -> None:
         path = fate_suite("sub/MovText_capability_tester.mp4")
 
         subs = []
@@ -23,8 +23,12 @@ class TestSubtitle(TestCase):
 
         sub = subset[0]
         self.assertIsInstance(sub, AssSubtitle)
+        assert isinstance(sub, AssSubtitle)
+
         self.assertEqual(sub.type, b"ass")
+        self.assertEqual(sub.text, b"")
         self.assertEqual(sub.ass, b"0,0,Default,,0,0,0,,- Test 1.\\N- Test 2.")
+        self.assertEqual(sub.dialogue, b"- Test 1.\n- Test 2.")
 
     def test_vobsub(self):
         path = fate_suite("sub/vobsub.sub")
@@ -54,3 +58,15 @@ class TestSubtitle(TestCase):
         bms = sub.planes
         self.assertEqual(len(bms), 1)
         self.assertEqual(len(memoryview(bms[0])), 4800)
+
+    def test_subtitle_flush(self) -> None:
+        path = fate_suite("sub/MovText_capability_tester.mp4")
+
+        subs = []
+        with av.open(path) as container:
+            stream = container.streams.subtitles[0]
+            for packet in container.demux(stream):
+                subs.extend(stream.decode(packet))
+                subs.extend(stream.decode())
+
+        self.assertEqual(len(subs), 3)
